==> image_editor_pro-1.0.8.tar.gz: example/lib/main.dart <==
import 'dart:io';
import 'package:image_editor_pro/image_editor_pro.dart';
import 'package:firexcode/firexcode.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return HomePage().xMaterialApp();
  }
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  File _image;

  Future<void> getimageditor() =>
      Navigator.push(context, MaterialPageRoute(builder: (context) {
        return ImageEditorPro(
          appBarColor: Colors.blue,
          bottomBarColor: Colors.blue,
        );
      })).then((geteditimage) {
        if (geteditimage != null) {
          setState(() {
            _image = geteditimage;
          });
        }
      }).catchError((er) {
        print(er);
      });

  @override
  Widget build(BuildContext context) {
    return condition(
            condtion: _image == null,
            isTue: 'Open Editor'.text().xRaisedButton(
              onPressed: () {
                getimageditor();
              },
            ).toCenter(),
            isFalse: Image.file(_image).toCenter())
        .xScaffold(
            appBar:
                'Image Editor Pro example'.textMaterialColorWhite().xAppBar(),
            floatingActionButton:
                Icons.add.xIcons().xFloationActiobButton(color: Colors.red));
  }
}

Widget condition({bool condtion, Widget isTue, Widget isFalse}) {
  return condtion ? isTue : isFalse;
}

==> image_editor_pro-1.1.5.tar.gz: example/lib/main.dart <==
import 'dart:io';
import 'package:image_editor_pro/image_editor_pro.dart';
import 'package:firexcode/firexcode.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return HomePage().xMaterialApp();
  }
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  File _image;

  Future<void> getimageditor() =>
      Navigator.push(context, MaterialPageRoute(builder: (context) {
        return ImageEditorPro(
          appBarColor: Colors.blue,
          bottomBarColor: Colors.blue,
        );
      })).then((geteditimage) {
        if (geteditimage != null) {
          setState(() {
            _image = geteditimage;
          });
        }
      }).catchError((er) {
        print(er);
      });

  @override
  Widget build(BuildContext context) {
    return condition(
            condtion: _image == null,
            isTue: 'Open Editor'.text().xRaisedButton(
              onPressed: () {
                getimageditor();
              },
            ).toCenter(),
            isFalse: Image.file(_image).toCenter())
        .xScaffold(
            appBar: 'Image Editor Pro example'.xTextColorWhite().xAppBar(),
            floatingActionButton:
                Icons.add.xIcons().xFloationActiobButton(color: Colors.red));
  }
}

Widget condition({bool condtion, Widget isTue, Widget isFalse}) {
  return condtion ? isTue : isFalse;
}
